@@ -1,14 +1,15 @@
 #!/bin/sh
 echo 'name: haskell-src-exts
-version: 1.11.1
-id: haskell-src-exts-1.11.1-9d15ede58cc5d110e1f5207b5b53c319
+version: 1.13.3
+id: haskell-src-exts-1.13.3-18c24460d90b260251861c9a48614674
 
 license: BSD3
 copyright:
-maintainer: Niklas Broberg <d00nibro@chalmers.se>
+maintainer: Niklas Broberg <niklas.broberg@chalmers.se>
 stability: Stable
 homepage: http://code.haskell.org/haskell-src-exts
 package-url:
+synopsis: Manipulating Haskell source: abstract syntax, lexer, parser, and pretty-printer
 description: Haskell-Source with Extensions (HSE, haskell-src-exts)
              is an extension of the standard haskell-src package,
              and handles most registered syntactic extensions to Haskell, including:
@@ -47,22 +48,23 @@ hidden-modules: Language.Haskell.Exts.ExtScheme
                 Language.Haskell.Exts.ParseMonad Language.Haskell.Exts.ParseSyntax
                 Language.Haskell.Exts.Lexer Language.Haskell.Exts.ParseUtils
                 Language.Haskell.Exts.InternalParser
-import-dirs: /usr/local/lib/ghc/haskell-src-exts-1.11.1
-library-dirs: /usr/local/lib/ghc/haskell-src-exts-1.11.1
-hs-libraries: HShaskell-src-exts-1.11.1
+trusted: False
+import-dirs: /usr/local/lib/ghc/haskell-src-exts-1.13.3
+library-dirs: /usr/local/lib/ghc/haskell-src-exts-1.13.3
+hs-libraries: HShaskell-src-exts-1.13.3
 extra-libraries:
 extra-ghci-libraries:
 include-dirs:
 includes:
-depends: array-0.3.0.2-3444ee049e55c8df31a0796287f56a5e
-         base-4.3.1.0-e1ba2d2213b66179f3e0c901a27d3a96
-         cpphs-1.11-ae0dbfe075a323e48ed157f8dae0f0e2
-         pretty-1.0.1.2-6970e62db724fea03caad23f58dd8f86
+depends: array-0.4.0.1-3b78425c10ff2dad7acf7e8c8ae014c3
+         base-4.6.0.1-03845c6da2a0b3b4d0d49cc26c0cd3c0
+         cpphs-1.13.3-7402b0002a60f35ee0c31667e8bb7ad4
+         pretty-1.1.1.0-66181c695e6a2e173ba2088cf55cc396
 hugs-options:
 cc-options:
 ld-options:
 framework-dirs:
 frameworks:
-haddock-interfaces: /usr/local/share/doc/hs-haskell-src-exts-1.11.1/html/haskell-src-exts.haddock
-haddock-html: /usr/local/share/doc/hs-haskell-src-exts-1.11.1/html
-' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"
+haddock-interfaces: /usr/local/share/doc/hs-haskell-src-exts-1.13.3/html/haskell-src-exts.haddock
+haddock-html: /usr/local/share/doc/hs-haskell-src-exts-1.13.3/html
+' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
